==> ejc-outcontract-impl-3.0.0-20220127.034554-35-sources.jar: com/ejianc/foundation/outcontract/bean/ChangeOutcontractMaterialEntity.java <==
package com.ejianc.foundation.outcontract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 变更物资（周转材）合同价
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_outcontract_material")
public class ChangeOutcontractMaterialEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="change_outcontract_id")
    private Long changeOutcontractId; // 变更合同id
    @TableField(value="material_id")
    private Long materialId; // 物资id
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_code")
    private String materialCode; // 物资编码
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_spec")
    private String materialSpec; // 规格型号
    @TableField(value="material_unit")
    private String materialUnit; // 计量单位
    @TableField(value="strength_grade")
    private String strengthGrade; // 强度等级
    @TableField(value="brand_trademark")
    private String brandTrademark; // 品牌商标
    @TableField(value="quantity")
    private BigDecimal quantity; // 暂定数量
    @TableField(value="untax_unit_price")
    private BigDecimal untaxUnitPrice; // 不含税单价
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率（%）
    @TableField(value="tax_unit_price")
    private BigDecimal taxUnitPrice; // 含税单价
    @TableField(value="total_price")
    private BigDecimal totalPrice; // 合价
    @TableField(value="lease_term")
    private BigDecimal leaseTerm; // 租赁期（天）
    @TableField(value="remark")
    private String remark; // 备注
    
    
    

    public Long getChangeOutcontractId() {
        return changeOutcontractId;
    }

    public void setChangeOutcontractId(Long changeOutcontractId) {
        this.changeOutcontractId = changeOutcontractId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public String getMaterialUnit() {
        return materialUnit;
    }

    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    public String getStrengthGrade() {
        return strengthGrade;
    }

    public void setStrengthGrade(String strengthGrade) {
        this.strengthGrade = strengthGrade;
    }
    public String getBrandTrademark() {
        return brandTrademark;
    }

    public void setBrandTrademark(String brandTrademark) {
        this.brandTrademark = brandTrademark;
    }
    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getUntaxUnitPrice() {
        return untaxUnitPrice;
    }

    public void setUntaxUnitPrice(BigDecimal untaxUnitPrice) {
        this.untaxUnitPrice = untaxUnitPrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTaxUnitPrice() {
        return taxUnitPrice;
    }

    public void setTaxUnitPrice(BigDecimal taxUnitPrice) {
        this.taxUnitPrice = taxUnitPrice;
    }
    public BigDecimal getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(BigDecimal totalPrice) {
        this.totalPrice = totalPrice;
    }
    public BigDecimal getLeaseTerm() {
        return leaseTerm;
    }

    public void setLeaseTerm(BigDecimal leaseTerm) {
        this.leaseTerm = leaseTerm;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> ejc-outcontract-impl-3.0.0-20250930.034806-334-sources.jar: com/ejianc/foundation/outcontract/bean/ChangeOutcontractMaterialEntity.java <==
package com.ejianc.foundation.outcontract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 变更物资（周转材）合同价
 * 
 * @author generator
 * 
 */
 @TableName("ejc_change_outcontract_material")
public class ChangeOutcontractMaterialEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="change_outcontract_id")
    private Long changeOutcontractId; // 变更合同id
    @TableField(value="material_id")
    private Long materialId; // 物资id
    @TableField(value="material_category_id")
    private Long materialCategoryId; // 物资分类id
    @TableField(value="material_category_name")
    private String materialCategoryName; // 物资分类名称
    @TableField(value="material_category_code")
    private String materialCategoryCode; // 物资分类编码
    @TableField(value="material_code")
    private String materialCode; // 物资编码
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_spec")
    private String materialSpec; // 规格型号
    @TableField(value="material_unit")
    private String materialUnit; // 计量单位
    @TableField(value="strength_grade")
    private String strengthGrade; // 强度等级
    @TableField(value="brand_trademark")
    private String brandTrademark; // 品牌商标
    @TableField(value="quantity")
    private BigDecimal quantity; // 暂定数量
    @TableField(value="untax_unit_price")
    private BigDecimal untaxUnitPrice; // 不含税单价
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率（%）
    @TableField(value="tax_unit_price")
    private BigDecimal taxUnitPrice; // 含税单价
    @TableField(value="total_price")
    private BigDecimal totalPrice; // 合价
    @TableField(value="lease_term")
    private BigDecimal leaseTerm; // 租赁期（天）
    @TableField(value="remark")
    private String remark; // 备注
    
    
    

    public Long getChangeOutcontractId() {
        return changeOutcontractId;
    }

    public void setChangeOutcontractId(Long changeOutcontractId) {
        this.changeOutcontractId = changeOutcontractId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public Long getMaterialCategoryId() {
        return materialCategoryId;
    }

    public void setMaterialCategoryId(Long materialCategoryId) {
        this.materialCategoryId = materialCategoryId;
    }
    public String getMaterialCategoryName() {
        return materialCategoryName;
    }

    public void setMaterialCategoryName(String materialCategoryName) {
        this.materialCategoryName = materialCategoryName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getMaterialSpec() {
        return materialSpec;
    }

    public void setMaterialSpec(String materialSpec) {
        this.materialSpec = materialSpec;
    }
    public String getMaterialUnit() {
        return materialUnit;
    }

    public void setMaterialUnit(String materialUnit) {
        this.materialUnit = materialUnit;
    }
    public String getStrengthGrade() {
        return strengthGrade;
    }

    public void setStrengthGrade(String strengthGrade) {
        this.strengthGrade = strengthGrade;
    }
    public String getBrandTrademark() {
        return brandTrademark;
    }

    public void setBrandTrademark(String brandTrademark) {
        this.brandTrademark = brandTrademark;
    }
    public BigDecimal getQuantity() {
        return quantity;
    }

    public void setQuantity(BigDecimal quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getUntaxUnitPrice() {
        return untaxUnitPrice;
    }

    public void setUntaxUnitPrice(BigDecimal untaxUnitPrice) {
        this.untaxUnitPrice = untaxUnitPrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTaxUnitPrice() {
        return taxUnitPrice;
    }

    public void setTaxUnitPrice(BigDecimal taxUnitPrice) {
        this.taxUnitPrice = taxUnitPrice;
    }
    public BigDecimal getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(BigDecimal totalPrice) {
        this.totalPrice = totalPrice;
    }
    public BigDecimal getLeaseTerm() {
        return leaseTerm;
    }

    public void setLeaseTerm(BigDecimal leaseTerm) {
        this.leaseTerm = leaseTerm;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

	public String getMaterialCategoryCode() {
		return materialCategoryCode;
	}

	public void setMaterialCategoryCode(String materialCategoryCode) {
		this.materialCategoryCode = materialCategoryCode;
	}
    
}
